# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1GalleryComponent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'author': 'str',
        'authors': 'list[str]',
        'auto_start': 'bool',
        'categories': 'list[str]',
        'description': 'str',
        'display_name': 'str',
        'entrypoint_file': 'str',
        'example_code': 'str',
        'flow_servers': 'list[V1Flowserver]',
        'git_url': 'str',
        'hardware': 'str',
        'id': 'str',
        'installation_code': 'str',
        'license': 'str',
        'name': 'str',
        'open_url': 'str',
        'org_logo': 'str',
        'organization': 'str',
        'readme': 'str',
        'requirements_path': 'str',
        'short_description': 'str',
        'source_type': 'str',
        'source_url': 'str',
        'tags': 'list[str]',
        'thumbnail': 'str',
        'version': 'str',
        'video': 'str',
        'visibility': 'str',
        'works': 'list[V1Work]'
    }

    attribute_map = {
        'author': 'author',
        'authors': 'authors',
        'auto_start': 'autoStart',
        'categories': 'categories',
        'description': 'description',
        'display_name': 'displayName',
        'entrypoint_file': 'entrypointFile',
        'example_code': 'exampleCode',
        'flow_servers': 'flowServers',
        'git_url': 'gitUrl',
        'hardware': 'hardware',
        'id': 'id',
        'installation_code': 'installationCode',
        'license': 'license',
        'name': 'name',
        'open_url': 'openUrl',
        'org_logo': 'orgLogo',
        'organization': 'organization',
        'readme': 'readme',
        'requirements_path': 'requirementsPath',
        'short_description': 'shortDescription',
        'source_type': 'sourceType',
        'source_url': 'sourceUrl',
        'tags': 'tags',
        'thumbnail': 'thumbnail',
        'version': 'version',
        'video': 'video',
        'visibility': 'visibility',
        'works': 'works'
    }

    def __init__(self, author: 'str' =None, authors: 'list[str]' =None, auto_start: 'bool' =None, categories: 'list[str]' =None, description: 'str' =None, display_name: 'str' =None, entrypoint_file: 'str' =None, example_code: 'str' =None, flow_servers: 'list[V1Flowserver]' =None, git_url: 'str' =None, hardware: 'str' =None, id: 'str' =None, installation_code: 'str' =None, license: 'str' =None, name: 'str' =None, open_url: 'str' =None, org_logo: 'str' =None, organization: 'str' =None, readme: 'str' =None, requirements_path: 'str' =None, short_description: 'str' =None, source_type: 'str' =None, source_url: 'str' =None, tags: 'list[str]' =None, thumbnail: 'str' =None, version: 'str' =None, video: 'str' =None, visibility: 'str' =None, works: 'list[V1Work]' =None):  # noqa: E501
        """V1GalleryComponent - a model defined in Swagger"""  # noqa: E501
        self._author = None
        self._authors = None
        self._auto_start = None
        self._categories = None
        self._description = None
        self._display_name = None
        self._entrypoint_file = None
        self._example_code = None
        self._flow_servers = None
        self._git_url = None
        self._hardware = None
        self._id = None
        self._installation_code = None
        self._license = None
        self._name = None
        self._open_url = None
        self._org_logo = None
        self._organization = None
        self._readme = None
        self._requirements_path = None
        self._short_description = None
        self._source_type = None
        self._source_url = None
        self._tags = None
        self._thumbnail = None
        self._version = None
        self._video = None
        self._visibility = None
        self._works = None
        self.discriminator = None
        if author is not None:
            self.author = author
        if authors is not None:
            self.authors = authors
        if auto_start is not None:
            self.auto_start = auto_start
        if categories is not None:
            self.categories = categories
        if description is not None:
            self.description = description
        if display_name is not None:
            self.display_name = display_name
        if entrypoint_file is not None:
            self.entrypoint_file = entrypoint_file
        if example_code is not None:
            self.example_code = example_code
        if flow_servers is not None:
            self.flow_servers = flow_servers
        if git_url is not None:
            self.git_url = git_url
        if hardware is not None:
            self.hardware = hardware
        if id is not None:
            self.id = id
        if installation_code is not None:
            self.installation_code = installation_code
        if license is not None:
            self.license = license
        if name is not None:
            self.name = name
        if open_url is not None:
            self.open_url = open_url
        if org_logo is not None:
            self.org_logo = org_logo
        if organization is not None:
            self.organization = organization
        if readme is not None:
            self.readme = readme
        if requirements_path is not None:
            self.requirements_path = requirements_path
        if short_description is not None:
            self.short_description = short_description
        if source_type is not None:
            self.source_type = source_type
        if source_url is not None:
            self.source_url = source_url
        if tags is not None:
            self.tags = tags
        if thumbnail is not None:
            self.thumbnail = thumbnail
        if version is not None:
            self.version = version
        if video is not None:
            self.video = video
        if visibility is not None:
            self.visibility = visibility
        if works is not None:
            self.works = works

    @property
    def author(self) -> 'str':
        """Gets the author of this V1GalleryComponent.  # noqa: E501


        :return: The author of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._author

    @author.setter
    def author(self, author: 'str'):
        """Sets the author of this V1GalleryComponent.


        :param author: The author of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._author = author

    @property
    def authors(self) -> 'list[str]':
        """Gets the authors of this V1GalleryComponent.  # noqa: E501


        :return: The authors of this V1GalleryComponent.  # noqa: E501
        :rtype: list[str]
        """
        return self._authors

    @authors.setter
    def authors(self, authors: 'list[str]'):
        """Sets the authors of this V1GalleryComponent.


        :param authors: The authors of this V1GalleryComponent.  # noqa: E501
        :type: list[str]
        """

        self._authors = authors

    @property
    def auto_start(self) -> 'bool':
        """Gets the auto_start of this V1GalleryComponent.  # noqa: E501


        :return: The auto_start of this V1GalleryComponent.  # noqa: E501
        :rtype: bool
        """
        return self._auto_start

    @auto_start.setter
    def auto_start(self, auto_start: 'bool'):
        """Sets the auto_start of this V1GalleryComponent.


        :param auto_start: The auto_start of this V1GalleryComponent.  # noqa: E501
        :type: bool
        """

        self._auto_start = auto_start

    @property
    def categories(self) -> 'list[str]':
        """Gets the categories of this V1GalleryComponent.  # noqa: E501


        :return: The categories of this V1GalleryComponent.  # noqa: E501
        :rtype: list[str]
        """
        return self._categories

    @categories.setter
    def categories(self, categories: 'list[str]'):
        """Sets the categories of this V1GalleryComponent.


        :param categories: The categories of this V1GalleryComponent.  # noqa: E501
        :type: list[str]
        """

        self._categories = categories

    @property
    def description(self) -> 'str':
        """Gets the description of this V1GalleryComponent.  # noqa: E501


        :return: The description of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description: 'str'):
        """Sets the description of this V1GalleryComponent.


        :param description: The description of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def display_name(self) -> 'str':
        """Gets the display_name of this V1GalleryComponent.  # noqa: E501


        :return: The display_name of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name: 'str'):
        """Sets the display_name of this V1GalleryComponent.


        :param display_name: The display_name of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def entrypoint_file(self) -> 'str':
        """Gets the entrypoint_file of this V1GalleryComponent.  # noqa: E501


        :return: The entrypoint_file of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._entrypoint_file

    @entrypoint_file.setter
    def entrypoint_file(self, entrypoint_file: 'str'):
        """Sets the entrypoint_file of this V1GalleryComponent.


        :param entrypoint_file: The entrypoint_file of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._entrypoint_file = entrypoint_file

    @property
    def example_code(self) -> 'str':
        """Gets the example_code of this V1GalleryComponent.  # noqa: E501


        :return: The example_code of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._example_code

    @example_code.setter
    def example_code(self, example_code: 'str'):
        """Sets the example_code of this V1GalleryComponent.


        :param example_code: The example_code of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._example_code = example_code

    @property
    def flow_servers(self) -> 'list[V1Flowserver]':
        """Gets the flow_servers of this V1GalleryComponent.  # noqa: E501


        :return: The flow_servers of this V1GalleryComponent.  # noqa: E501
        :rtype: list[V1Flowserver]
        """
        return self._flow_servers

    @flow_servers.setter
    def flow_servers(self, flow_servers: 'list[V1Flowserver]'):
        """Sets the flow_servers of this V1GalleryComponent.


        :param flow_servers: The flow_servers of this V1GalleryComponent.  # noqa: E501
        :type: list[V1Flowserver]
        """

        self._flow_servers = flow_servers

    @property
    def git_url(self) -> 'str':
        """Gets the git_url of this V1GalleryComponent.  # noqa: E501


        :return: The git_url of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._git_url

    @git_url.setter
    def git_url(self, git_url: 'str'):
        """Sets the git_url of this V1GalleryComponent.


        :param git_url: The git_url of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._git_url = git_url

    @property
    def hardware(self) -> 'str':
        """Gets the hardware of this V1GalleryComponent.  # noqa: E501


        :return: The hardware of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._hardware

    @hardware.setter
    def hardware(self, hardware: 'str'):
        """Sets the hardware of this V1GalleryComponent.


        :param hardware: The hardware of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._hardware = hardware

    @property
    def id(self) -> 'str':
        """Gets the id of this V1GalleryComponent.  # noqa: E501


        :return: The id of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1GalleryComponent.


        :param id: The id of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def installation_code(self) -> 'str':
        """Gets the installation_code of this V1GalleryComponent.  # noqa: E501


        :return: The installation_code of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._installation_code

    @installation_code.setter
    def installation_code(self, installation_code: 'str'):
        """Sets the installation_code of this V1GalleryComponent.


        :param installation_code: The installation_code of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._installation_code = installation_code

    @property
    def license(self) -> 'str':
        """Gets the license of this V1GalleryComponent.  # noqa: E501


        :return: The license of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._license

    @license.setter
    def license(self, license: 'str'):
        """Sets the license of this V1GalleryComponent.


        :param license: The license of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._license = license

    @property
    def name(self) -> 'str':
        """Gets the name of this V1GalleryComponent.  # noqa: E501


        :return: The name of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name: 'str'):
        """Sets the name of this V1GalleryComponent.


        :param name: The name of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def open_url(self) -> 'str':
        """Gets the open_url of this V1GalleryComponent.  # noqa: E501


        :return: The open_url of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._open_url

    @open_url.setter
    def open_url(self, open_url: 'str'):
        """Sets the open_url of this V1GalleryComponent.


        :param open_url: The open_url of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._open_url = open_url

    @property
    def org_logo(self) -> 'str':
        """Gets the org_logo of this V1GalleryComponent.  # noqa: E501


        :return: The org_logo of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._org_logo

    @org_logo.setter
    def org_logo(self, org_logo: 'str'):
        """Sets the org_logo of this V1GalleryComponent.


        :param org_logo: The org_logo of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._org_logo = org_logo

    @property
    def organization(self) -> 'str':
        """Gets the organization of this V1GalleryComponent.  # noqa: E501


        :return: The organization of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._organization

    @organization.setter
    def organization(self, organization: 'str'):
        """Sets the organization of this V1GalleryComponent.


        :param organization: The organization of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._organization = organization

    @property
    def readme(self) -> 'str':
        """Gets the readme of this V1GalleryComponent.  # noqa: E501


        :return: The readme of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._readme

    @readme.setter
    def readme(self, readme: 'str'):
        """Sets the readme of this V1GalleryComponent.


        :param readme: The readme of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._readme = readme

    @property
    def requirements_path(self) -> 'str':
        """Gets the requirements_path of this V1GalleryComponent.  # noqa: E501


        :return: The requirements_path of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._requirements_path

    @requirements_path.setter
    def requirements_path(self, requirements_path: 'str'):
        """Sets the requirements_path of this V1GalleryComponent.


        :param requirements_path: The requirements_path of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._requirements_path = requirements_path

    @property
    def short_description(self) -> 'str':
        """Gets the short_description of this V1GalleryComponent.  # noqa: E501


        :return: The short_description of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._short_description

    @short_description.setter
    def short_description(self, short_description: 'str'):
        """Sets the short_description of this V1GalleryComponent.


        :param short_description: The short_description of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._short_description = short_description

    @property
    def source_type(self) -> 'str':
        """Gets the source_type of this V1GalleryComponent.  # noqa: E501


        :return: The source_type of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._source_type

    @source_type.setter
    def source_type(self, source_type: 'str'):
        """Sets the source_type of this V1GalleryComponent.


        :param source_type: The source_type of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._source_type = source_type

    @property
    def source_url(self) -> 'str':
        """Gets the source_url of this V1GalleryComponent.  # noqa: E501


        :return: The source_url of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._source_url

    @source_url.setter
    def source_url(self, source_url: 'str'):
        """Sets the source_url of this V1GalleryComponent.


        :param source_url: The source_url of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._source_url = source_url

    @property
    def tags(self) -> 'list[str]':
        """Gets the tags of this V1GalleryComponent.  # noqa: E501


        :return: The tags of this V1GalleryComponent.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags: 'list[str]'):
        """Sets the tags of this V1GalleryComponent.


        :param tags: The tags of this V1GalleryComponent.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def thumbnail(self) -> 'str':
        """Gets the thumbnail of this V1GalleryComponent.  # noqa: E501


        :return: The thumbnail of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail

    @thumbnail.setter
    def thumbnail(self, thumbnail: 'str'):
        """Sets the thumbnail of this V1GalleryComponent.


        :param thumbnail: The thumbnail of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._thumbnail = thumbnail

    @property
    def version(self) -> 'str':
        """Gets the version of this V1GalleryComponent.  # noqa: E501


        :return: The version of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version: 'str'):
        """Sets the version of this V1GalleryComponent.


        :param version: The version of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def video(self) -> 'str':
        """Gets the video of this V1GalleryComponent.  # noqa: E501


        :return: The video of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._video

    @video.setter
    def video(self, video: 'str'):
        """Sets the video of this V1GalleryComponent.


        :param video: The video of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._video = video

    @property
    def visibility(self) -> 'str':
        """Gets the visibility of this V1GalleryComponent.  # noqa: E501


        :return: The visibility of this V1GalleryComponent.  # noqa: E501
        :rtype: str
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility: 'str'):
        """Sets the visibility of this V1GalleryComponent.


        :param visibility: The visibility of this V1GalleryComponent.  # noqa: E501
        :type: str
        """

        self._visibility = visibility

    @property
    def works(self) -> 'list[V1Work]':
        """Gets the works of this V1GalleryComponent.  # noqa: E501


        :return: The works of this V1GalleryComponent.  # noqa: E501
        :rtype: list[V1Work]
        """
        return self._works

    @works.setter
    def works(self, works: 'list[V1Work]'):
        """Sets the works of this V1GalleryComponent.


        :param works: The works of this V1GalleryComponent.  # noqa: E501
        :type: list[V1Work]
        """

        self._works = works

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1GalleryComponent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1GalleryComponent') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1GalleryComponent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1GalleryComponent') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1CPUSystemMetrics(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'block_read': 'int',
        'block_write': 'int',
        'memory_percentage': 'int',
        'memory_total': 'int',
        'memory_used': 'int',
        'network_rx': 'int',
        'network_tx': 'int',
        'percentage': 'int',
        'percentage_per_cpu': 'list[float]'
    }

    attribute_map = {
        'block_read': 'blockRead',
        'block_write': 'blockWrite',
        'memory_percentage': 'memoryPercentage',
        'memory_total': 'memoryTotal',
        'memory_used': 'memoryUsed',
        'network_rx': 'networkRx',
        'network_tx': 'networkTx',
        'percentage': 'percentage',
        'percentage_per_cpu': 'percentagePerCpu'
    }

    def __init__(self, block_read: 'int' =None, block_write: 'int' =None, memory_percentage: 'int' =None, memory_total: 'int' =None, memory_used: 'int' =None, network_rx: 'int' =None, network_tx: 'int' =None, percentage: 'int' =None, percentage_per_cpu: 'list[float]' =None):  # noqa: E501
        """V1CPUSystemMetrics - a model defined in Swagger"""  # noqa: E501
        self._block_read = None
        self._block_write = None
        self._memory_percentage = None
        self._memory_total = None
        self._memory_used = None
        self._network_rx = None
        self._network_tx = None
        self._percentage = None
        self._percentage_per_cpu = None
        self.discriminator = None
        if block_read is not None:
            self.block_read = block_read
        if block_write is not None:
            self.block_write = block_write
        if memory_percentage is not None:
            self.memory_percentage = memory_percentage
        if memory_total is not None:
            self.memory_total = memory_total
        if memory_used is not None:
            self.memory_used = memory_used
        if network_rx is not None:
            self.network_rx = network_rx
        if network_tx is not None:
            self.network_tx = network_tx
        if percentage is not None:
            self.percentage = percentage
        if percentage_per_cpu is not None:
            self.percentage_per_cpu = percentage_per_cpu

    @property
    def block_read(self) -> 'int':
        """Gets the block_read of this V1CPUSystemMetrics.  # noqa: E501


        :return: The block_read of this V1CPUSystemMetrics.  # noqa: E501
        :rtype: int
        """
        return self._block_read

    @block_read.setter
    def block_read(self, block_read: 'int'):
        """Sets the block_read of this V1CPUSystemMetrics.


        :param block_read: The block_read of this V1CPUSystemMetrics.  # noqa: E501
        :type: int
        """

        self._block_read = block_read

    @property
    def block_write(self) -> 'int':
        """Gets the block_write of this V1CPUSystemMetrics.  # noqa: E501


        :return: The block_write of this V1CPUSystemMetrics.  # noqa: E501
        :rtype: int
        """
        return self._block_write

    @block_write.setter
    def block_write(self, block_write: 'int'):
        """Sets the block_write of this V1CPUSystemMetrics.


        :param block_write: The block_write of this V1CPUSystemMetrics.  # noqa: E501
        :type: int
        """

        self._block_write = block_write

    @property
    def memory_percentage(self) -> 'int':
        """Gets the memory_percentage of this V1CPUSystemMetrics.  # noqa: E501


        :return: The memory_percentage of this V1CPUSystemMetrics.  # noqa: E501
        :rtype: int
        """
        return self._memory_percentage

    @memory_percentage.setter
    def memory_percentage(self, memory_percentage: 'int'):
        """Sets the memory_percentage of this V1CPUSystemMetrics.


        :param memory_percentage: The memory_percentage of this V1CPUSystemMetrics.  # noqa: E501
        :type: int
        """

        self._memory_percentage = memory_percentage

    @property
    def memory_total(self) -> 'int':
        """Gets the memory_total of this V1CPUSystemMetrics.  # noqa: E501


        :return: The memory_total of this V1CPUSystemMetrics.  # noqa: E501
        :rtype: int
        """
        return self._memory_total

    @memory_total.setter
    def memory_total(self, memory_total: 'int'):
        """Sets the memory_total of this V1CPUSystemMetrics.


        :param memory_total: The memory_total of this V1CPUSystemMetrics.  # noqa: E501
        :type: int
        """

        self._memory_total = memory_total

    @property
    def memory_used(self) -> 'int':
        """Gets the memory_used of this V1CPUSystemMetrics.  # noqa: E501


        :return: The memory_used of this V1CPUSystemMetrics.  # noqa: E501
        :rtype: int
        """
        return self._memory_used

    @memory_used.setter
    def memory_used(self, memory_used: 'int'):
        """Sets the memory_used of this V1CPUSystemMetrics.


        :param memory_used: The memory_used of this V1CPUSystemMetrics.  # noqa: E501
        :type: int
        """

        self._memory_used = memory_used

    @property
    def network_rx(self) -> 'int':
        """Gets the network_rx of this V1CPUSystemMetrics.  # noqa: E501


        :return: The network_rx of this V1CPUSystemMetrics.  # noqa: E501
        :rtype: int
        """
        return self._network_rx

    @network_rx.setter
    def network_rx(self, network_rx: 'int'):
        """Sets the network_rx of this V1CPUSystemMetrics.


        :param network_rx: The network_rx of this V1CPUSystemMetrics.  # noqa: E501
        :type: int
        """

        self._network_rx = network_rx

    @property
    def network_tx(self) -> 'int':
        """Gets the network_tx of this V1CPUSystemMetrics.  # noqa: E501


        :return: The network_tx of this V1CPUSystemMetrics.  # noqa: E501
        :rtype: int
        """
        return self._network_tx

    @network_tx.setter
    def network_tx(self, network_tx: 'int'):
        """Sets the network_tx of this V1CPUSystemMetrics.


        :param network_tx: The network_tx of this V1CPUSystemMetrics.  # noqa: E501
        :type: int
        """

        self._network_tx = network_tx

    @property
    def percentage(self) -> 'int':
        """Gets the percentage of this V1CPUSystemMetrics.  # noqa: E501


        :return: The percentage of this V1CPUSystemMetrics.  # noqa: E501
        :rtype: int
        """
        return self._percentage

    @percentage.setter
    def percentage(self, percentage: 'int'):
        """Sets the percentage of this V1CPUSystemMetrics.


        :param percentage: The percentage of this V1CPUSystemMetrics.  # noqa: E501
        :type: int
        """

        self._percentage = percentage

    @property
    def percentage_per_cpu(self) -> 'list[float]':
        """Gets the percentage_per_cpu of this V1CPUSystemMetrics.  # noqa: E501


        :return: The percentage_per_cpu of this V1CPUSystemMetrics.  # noqa: E501
        :rtype: list[float]
        """
        return self._percentage_per_cpu

    @percentage_per_cpu.setter
    def percentage_per_cpu(self, percentage_per_cpu: 'list[float]'):
        """Sets the percentage_per_cpu of this V1CPUSystemMetrics.


        :param percentage_per_cpu: The percentage_per_cpu of this V1CPUSystemMetrics.  # noqa: E501
        :type: list[float]
        """

        self._percentage_per_cpu = percentage_per_cpu

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1CPUSystemMetrics, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1CPUSystemMetrics') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1CPUSystemMetrics):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1CPUSystemMetrics') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1BillingFeature(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'current_usage': 'int',
        'hit_limit': 'bool',
        'key': 'str',
        'limit': 'int',
        'upgrade_path': 'str'
    }

    attribute_map = {
        'current_usage': 'currentUsage',
        'hit_limit': 'hitLimit',
        'key': 'key',
        'limit': 'limit',
        'upgrade_path': 'upgradePath'
    }

    def __init__(self, current_usage: 'int' =None, hit_limit: 'bool' =None, key: 'str' =None, limit: 'int' =None, upgrade_path: 'str' =None):  # noqa: E501
        """V1BillingFeature - a model defined in Swagger"""  # noqa: E501
        self._current_usage = None
        self._hit_limit = None
        self._key = None
        self._limit = None
        self._upgrade_path = None
        self.discriminator = None
        if current_usage is not None:
            self.current_usage = current_usage
        if hit_limit is not None:
            self.hit_limit = hit_limit
        if key is not None:
            self.key = key
        if limit is not None:
            self.limit = limit
        if upgrade_path is not None:
            self.upgrade_path = upgrade_path

    @property
    def current_usage(self) -> 'int':
        """Gets the current_usage of this V1BillingFeature.  # noqa: E501


        :return: The current_usage of this V1BillingFeature.  # noqa: E501
        :rtype: int
        """
        return self._current_usage

    @current_usage.setter
    def current_usage(self, current_usage: 'int'):
        """Sets the current_usage of this V1BillingFeature.


        :param current_usage: The current_usage of this V1BillingFeature.  # noqa: E501
        :type: int
        """

        self._current_usage = current_usage

    @property
    def hit_limit(self) -> 'bool':
        """Gets the hit_limit of this V1BillingFeature.  # noqa: E501


        :return: The hit_limit of this V1BillingFeature.  # noqa: E501
        :rtype: bool
        """
        return self._hit_limit

    @hit_limit.setter
    def hit_limit(self, hit_limit: 'bool'):
        """Sets the hit_limit of this V1BillingFeature.


        :param hit_limit: The hit_limit of this V1BillingFeature.  # noqa: E501
        :type: bool
        """

        self._hit_limit = hit_limit

    @property
    def key(self) -> 'str':
        """Gets the key of this V1BillingFeature.  # noqa: E501


        :return: The key of this V1BillingFeature.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key: 'str'):
        """Sets the key of this V1BillingFeature.


        :param key: The key of this V1BillingFeature.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def limit(self) -> 'int':
        """Gets the limit of this V1BillingFeature.  # noqa: E501


        :return: The limit of this V1BillingFeature.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit: 'int'):
        """Sets the limit of this V1BillingFeature.


        :param limit: The limit of this V1BillingFeature.  # noqa: E501
        :type: int
        """

        self._limit = limit

    @property
    def upgrade_path(self) -> 'str':
        """Gets the upgrade_path of this V1BillingFeature.  # noqa: E501


        :return: The upgrade_path of this V1BillingFeature.  # noqa: E501
        :rtype: str
        """
        return self._upgrade_path

    @upgrade_path.setter
    def upgrade_path(self, upgrade_path: 'str'):
        """Sets the upgrade_path of this V1BillingFeature.


        :param upgrade_path: The upgrade_path of this V1BillingFeature.  # noqa: E501
        :type: str
        """

        self._upgrade_path = upgrade_path

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1BillingFeature, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1BillingFeature') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1BillingFeature):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1BillingFeature') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1GPUSystemMetrics(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'memory_total': 'int',
        'memory_used': 'int',
        'power_draw': 'int',
        'temperature': 'int',
        'utilisation': 'int',
        'utilisation_memory': 'int'
    }

    attribute_map = {
        'memory_total': 'memoryTotal',
        'memory_used': 'memoryUsed',
        'power_draw': 'powerDraw',
        'temperature': 'temperature',
        'utilisation': 'utilisation',
        'utilisation_memory': 'utilisationMemory'
    }

    def __init__(self, memory_total: 'int' =None, memory_used: 'int' =None, power_draw: 'int' =None, temperature: 'int' =None, utilisation: 'int' =None, utilisation_memory: 'int' =None):  # noqa: E501
        """V1GPUSystemMetrics - a model defined in Swagger"""  # noqa: E501
        self._memory_total = None
        self._memory_used = None
        self._power_draw = None
        self._temperature = None
        self._utilisation = None
        self._utilisation_memory = None
        self.discriminator = None
        if memory_total is not None:
            self.memory_total = memory_total
        if memory_used is not None:
            self.memory_used = memory_used
        if power_draw is not None:
            self.power_draw = power_draw
        if temperature is not None:
            self.temperature = temperature
        if utilisation is not None:
            self.utilisation = utilisation
        if utilisation_memory is not None:
            self.utilisation_memory = utilisation_memory

    @property
    def memory_total(self) -> 'int':
        """Gets the memory_total of this V1GPUSystemMetrics.  # noqa: E501


        :return: The memory_total of this V1GPUSystemMetrics.  # noqa: E501
        :rtype: int
        """
        return self._memory_total

    @memory_total.setter
    def memory_total(self, memory_total: 'int'):
        """Sets the memory_total of this V1GPUSystemMetrics.


        :param memory_total: The memory_total of this V1GPUSystemMetrics.  # noqa: E501
        :type: int
        """

        self._memory_total = memory_total

    @property
    def memory_used(self) -> 'int':
        """Gets the memory_used of this V1GPUSystemMetrics.  # noqa: E501


        :return: The memory_used of this V1GPUSystemMetrics.  # noqa: E501
        :rtype: int
        """
        return self._memory_used

    @memory_used.setter
    def memory_used(self, memory_used: 'int'):
        """Sets the memory_used of this V1GPUSystemMetrics.


        :param memory_used: The memory_used of this V1GPUSystemMetrics.  # noqa: E501
        :type: int
        """

        self._memory_used = memory_used

    @property
    def power_draw(self) -> 'int':
        """Gets the power_draw of this V1GPUSystemMetrics.  # noqa: E501


        :return: The power_draw of this V1GPUSystemMetrics.  # noqa: E501
        :rtype: int
        """
        return self._power_draw

    @power_draw.setter
    def power_draw(self, power_draw: 'int'):
        """Sets the power_draw of this V1GPUSystemMetrics.


        :param power_draw: The power_draw of this V1GPUSystemMetrics.  # noqa: E501
        :type: int
        """

        self._power_draw = power_draw

    @property
    def temperature(self) -> 'int':
        """Gets the temperature of this V1GPUSystemMetrics.  # noqa: E501


        :return: The temperature of this V1GPUSystemMetrics.  # noqa: E501
        :rtype: int
        """
        return self._temperature

    @temperature.setter
    def temperature(self, temperature: 'int'):
        """Sets the temperature of this V1GPUSystemMetrics.


        :param temperature: The temperature of this V1GPUSystemMetrics.  # noqa: E501
        :type: int
        """

        self._temperature = temperature

    @property
    def utilisation(self) -> 'int':
        """Gets the utilisation of this V1GPUSystemMetrics.  # noqa: E501


        :return: The utilisation of this V1GPUSystemMetrics.  # noqa: E501
        :rtype: int
        """
        return self._utilisation

    @utilisation.setter
    def utilisation(self, utilisation: 'int'):
        """Sets the utilisation of this V1GPUSystemMetrics.


        :param utilisation: The utilisation of this V1GPUSystemMetrics.  # noqa: E501
        :type: int
        """

        self._utilisation = utilisation

    @property
    def utilisation_memory(self) -> 'int':
        """Gets the utilisation_memory of this V1GPUSystemMetrics.  # noqa: E501


        :return: The utilisation_memory of this V1GPUSystemMetrics.  # noqa: E501
        :rtype: int
        """
        return self._utilisation_memory

    @utilisation_memory.setter
    def utilisation_memory(self, utilisation_memory: 'int'):
        """Sets the utilisation_memory of this V1GPUSystemMetrics.


        :param utilisation_memory: The utilisation_memory of this V1GPUSystemMetrics.  # noqa: E501
        :type: int
        """

        self._utilisation_memory = utilisation_memory

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1GPUSystemMetrics, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1GPUSystemMetrics') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1GPUSystemMetrics):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1GPUSystemMetrics') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class CloudspacesIdBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data_connection_mounts': 'list[V1DataConnectionMount]',
        'description': 'str',
        'display_name': 'str',
        'env': 'list[V1EnvVar]',
        'is_cloudspace_private': 'bool',
        'is_code_private': 'bool',
        'is_published': 'bool',
        'publish_with_compute_name': 'str',
        'tags': 'list[V1CloudSpaceTag]',
        'thumbnail': 'str',
        'thumbnail_file_type': 'str',
        'user_metadata': 'str'
    }

    attribute_map = {
        'data_connection_mounts': 'dataConnectionMounts',
        'description': 'description',
        'display_name': 'displayName',
        'env': 'env',
        'is_cloudspace_private': 'isCloudspacePrivate',
        'is_code_private': 'isCodePrivate',
        'is_published': 'isPublished',
        'publish_with_compute_name': 'publishWithComputeName',
        'tags': 'tags',
        'thumbnail': 'thumbnail',
        'thumbnail_file_type': 'thumbnailFileType',
        'user_metadata': 'userMetadata'
    }

    def __init__(self, data_connection_mounts: 'list[V1DataConnectionMount]' =None, description: 'str' =None, display_name: 'str' =None, env: 'list[V1EnvVar]' =None, is_cloudspace_private: 'bool' =None, is_code_private: 'bool' =None, is_published: 'bool' =None, publish_with_compute_name: 'str' =None, tags: 'list[V1CloudSpaceTag]' =None, thumbnail: 'str' =None, thumbnail_file_type: 'str' =None, user_metadata: 'str' =None):  # noqa: E501
        """CloudspacesIdBody - a model defined in Swagger"""  # noqa: E501
        self._data_connection_mounts = None
        self._description = None
        self._display_name = None
        self._env = None
        self._is_cloudspace_private = None
        self._is_code_private = None
        self._is_published = None
        self._publish_with_compute_name = None
        self._tags = None
        self._thumbnail = None
        self._thumbnail_file_type = None
        self._user_metadata = None
        self.discriminator = None
        if data_connection_mounts is not None:
            self.data_connection_mounts = data_connection_mounts
        if description is not None:
            self.description = description
        if display_name is not None:
            self.display_name = display_name
        if env is not None:
            self.env = env
        if is_cloudspace_private is not None:
            self.is_cloudspace_private = is_cloudspace_private
        if is_code_private is not None:
            self.is_code_private = is_code_private
        if is_published is not None:
            self.is_published = is_published
        if publish_with_compute_name is not None:
            self.publish_with_compute_name = publish_with_compute_name
        if tags is not None:
            self.tags = tags
        if thumbnail is not None:
            self.thumbnail = thumbnail
        if thumbnail_file_type is not None:
            self.thumbnail_file_type = thumbnail_file_type
        if user_metadata is not None:
            self.user_metadata = user_metadata

    @property
    def data_connection_mounts(self) -> 'list[V1DataConnectionMount]':
        """Gets the data_connection_mounts of this CloudspacesIdBody.  # noqa: E501


        :return: The data_connection_mounts of this CloudspacesIdBody.  # noqa: E501
        :rtype: list[V1DataConnectionMount]
        """
        return self._data_connection_mounts

    @data_connection_mounts.setter
    def data_connection_mounts(self, data_connection_mounts: 'list[V1DataConnectionMount]'):
        """Sets the data_connection_mounts of this CloudspacesIdBody.


        :param data_connection_mounts: The data_connection_mounts of this CloudspacesIdBody.  # noqa: E501
        :type: list[V1DataConnectionMount]
        """

        self._data_connection_mounts = data_connection_mounts

    @property
    def description(self) -> 'str':
        """Gets the description of this CloudspacesIdBody.  # noqa: E501


        :return: The description of this CloudspacesIdBody.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description: 'str'):
        """Sets the description of this CloudspacesIdBody.


        :param description: The description of this CloudspacesIdBody.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def display_name(self) -> 'str':
        """Gets the display_name of this CloudspacesIdBody.  # noqa: E501


        :return: The display_name of this CloudspacesIdBody.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name: 'str'):
        """Sets the display_name of this CloudspacesIdBody.


        :param display_name: The display_name of this CloudspacesIdBody.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def env(self) -> 'list[V1EnvVar]':
        """Gets the env of this CloudspacesIdBody.  # noqa: E501


        :return: The env of this CloudspacesIdBody.  # noqa: E501
        :rtype: list[V1EnvVar]
        """
        return self._env

    @env.setter
    def env(self, env: 'list[V1EnvVar]'):
        """Sets the env of this CloudspacesIdBody.


        :param env: The env of this CloudspacesIdBody.  # noqa: E501
        :type: list[V1EnvVar]
        """

        self._env = env

    @property
    def is_cloudspace_private(self) -> 'bool':
        """Gets the is_cloudspace_private of this CloudspacesIdBody.  # noqa: E501


        :return: The is_cloudspace_private of this CloudspacesIdBody.  # noqa: E501
        :rtype: bool
        """
        return self._is_cloudspace_private

    @is_cloudspace_private.setter
    def is_cloudspace_private(self, is_cloudspace_private: 'bool'):
        """Sets the is_cloudspace_private of this CloudspacesIdBody.


        :param is_cloudspace_private: The is_cloudspace_private of this CloudspacesIdBody.  # noqa: E501
        :type: bool
        """

        self._is_cloudspace_private = is_cloudspace_private

    @property
    def is_code_private(self) -> 'bool':
        """Gets the is_code_private of this CloudspacesIdBody.  # noqa: E501


        :return: The is_code_private of this CloudspacesIdBody.  # noqa: E501
        :rtype: bool
        """
        return self._is_code_private

    @is_code_private.setter
    def is_code_private(self, is_code_private: 'bool'):
        """Sets the is_code_private of this CloudspacesIdBody.


        :param is_code_private: The is_code_private of this CloudspacesIdBody.  # noqa: E501
        :type: bool
        """

        self._is_code_private = is_code_private

    @property
    def is_published(self) -> 'bool':
        """Gets the is_published of this CloudspacesIdBody.  # noqa: E501


        :return: The is_published of this CloudspacesIdBody.  # noqa: E501
        :rtype: bool
        """
        return self._is_published

    @is_published.setter
    def is_published(self, is_published: 'bool'):
        """Sets the is_published of this CloudspacesIdBody.


        :param is_published: The is_published of this CloudspacesIdBody.  # noqa: E501
        :type: bool
        """

        self._is_published = is_published

    @property
    def publish_with_compute_name(self) -> 'str':
        """Gets the publish_with_compute_name of this CloudspacesIdBody.  # noqa: E501


        :return: The publish_with_compute_name of this CloudspacesIdBody.  # noqa: E501
        :rtype: str
        """
        return self._publish_with_compute_name

    @publish_with_compute_name.setter
    def publish_with_compute_name(self, publish_with_compute_name: 'str'):
        """Sets the publish_with_compute_name of this CloudspacesIdBody.


        :param publish_with_compute_name: The publish_with_compute_name of this CloudspacesIdBody.  # noqa: E501
        :type: str
        """

        self._publish_with_compute_name = publish_with_compute_name

    @property
    def tags(self) -> 'list[V1CloudSpaceTag]':
        """Gets the tags of this CloudspacesIdBody.  # noqa: E501


        :return: The tags of this CloudspacesIdBody.  # noqa: E501
        :rtype: list[V1CloudSpaceTag]
        """
        return self._tags

    @tags.setter
    def tags(self, tags: 'list[V1CloudSpaceTag]'):
        """Sets the tags of this CloudspacesIdBody.


        :param tags: The tags of this CloudspacesIdBody.  # noqa: E501
        :type: list[V1CloudSpaceTag]
        """

        self._tags = tags

    @property
    def thumbnail(self) -> 'str':
        """Gets the thumbnail of this CloudspacesIdBody.  # noqa: E501


        :return: The thumbnail of this CloudspacesIdBody.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail

    @thumbnail.setter
    def thumbnail(self, thumbnail: 'str'):
        """Sets the thumbnail of this CloudspacesIdBody.


        :param thumbnail: The thumbnail of this CloudspacesIdBody.  # noqa: E501
        :type: str
        """

        self._thumbnail = thumbnail

    @property
    def thumbnail_file_type(self) -> 'str':
        """Gets the thumbnail_file_type of this CloudspacesIdBody.  # noqa: E501


        :return: The thumbnail_file_type of this CloudspacesIdBody.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail_file_type

    @thumbnail_file_type.setter
    def thumbnail_file_type(self, thumbnail_file_type: 'str'):
        """Sets the thumbnail_file_type of this CloudspacesIdBody.


        :param thumbnail_file_type: The thumbnail_file_type of this CloudspacesIdBody.  # noqa: E501
        :type: str
        """

        self._thumbnail_file_type = thumbnail_file_type

    @property
    def user_metadata(self) -> 'str':
        """Gets the user_metadata of this CloudspacesIdBody.  # noqa: E501


        :return: The user_metadata of this CloudspacesIdBody.  # noqa: E501
        :rtype: str
        """
        return self._user_metadata

    @user_metadata.setter
    def user_metadata(self, user_metadata: 'str'):
        """Sets the user_metadata of this CloudspacesIdBody.


        :param user_metadata: The user_metadata of this CloudspacesIdBody.  # noqa: E501
        :type: str
        """

        self._user_metadata = user_metadata

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CloudspacesIdBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'CloudspacesIdBody') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, CloudspacesIdBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'CloudspacesIdBody') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

from __future__ import absolute_import

import re  # noqa: F401
from typing import TYPE_CHECKING, Any

# python 2 and python 3 compatibility library
import six

from lightning_cloud.openapi.api_client import ApiClient

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class SlurmJobsUserServiceApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def slurm_jobs_user_service_create_user_slurm_job(self, body: 'SlurmJobsBody', project_id: 'str', **kwargs) -> 'V1SLURMJob':  # noqa: E501
        """CreateUserSLURMJob is used to create a new SLURM job for an authenticated user. For creating SLURM Jobs from an agent, please use the SLURMJobsAgentService.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.slurm_jobs_user_service_create_user_slurm_job(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SlurmJobsBody body: (required)
        :param str project_id: (required)
        :return: V1SLURMJob
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.slurm_jobs_user_service_create_user_slurm_job_with_http_info(body, project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.slurm_jobs_user_service_create_user_slurm_job_with_http_info(body, project_id, **kwargs)  # noqa: E501
            return data

    def slurm_jobs_user_service_create_user_slurm_job_with_http_info(self, body: 'SlurmJobsBody', project_id: 'str', **kwargs) -> 'V1SLURMJob':  # noqa: E501
        """CreateUserSLURMJob is used to create a new SLURM job for an authenticated user. For creating SLURM Jobs from an agent, please use the SLURMJobsAgentService.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.slurm_jobs_user_service_create_user_slurm_job_with_http_info(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SlurmJobsBody body: (required)
        :param str project_id: (required)
        :return: V1SLURMJob
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method slurm_jobs_user_service_create_user_slurm_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `slurm_jobs_user_service_create_user_slurm_job`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `slurm_jobs_user_service_create_user_slurm_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/slurm/jobs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1SLURMJob',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def slurm_jobs_user_service_delete_user_slurm_job(self, project_id: 'str', id: 'str', **kwargs) -> 'V1DeleteUserSLURMJobResponse':  # noqa: E501
        """DeleteUserSLURMJob is used to delete a specific SLURM job for an authenticated user. For deleting SLURM Jobs from an agent, please use the SLURMJobsAgentService.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.slurm_jobs_user_service_delete_user_slurm_job(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: V1DeleteUserSLURMJobResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.slurm_jobs_user_service_delete_user_slurm_job_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.slurm_jobs_user_service_delete_user_slurm_job_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def slurm_jobs_user_service_delete_user_slurm_job_with_http_info(self, project_id: 'str', id: 'str', **kwargs) -> 'V1DeleteUserSLURMJobResponse':  # noqa: E501
        """DeleteUserSLURMJob is used to delete a specific SLURM job for an authenticated user. For deleting SLURM Jobs from an agent, please use the SLURMJobsAgentService.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.slurm_jobs_user_service_delete_user_slurm_job_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: V1DeleteUserSLURMJobResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method slurm_jobs_user_service_delete_user_slurm_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `slurm_jobs_user_service_delete_user_slurm_job`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `slurm_jobs_user_service_delete_user_slurm_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/slurm/jobs/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1DeleteUserSLURMJobResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def slurm_jobs_user_service_get_user_slurm_job(self, project_id: 'str', id: 'str', **kwargs) -> 'V1SLURMJob':  # noqa: E501
        """GetUserSLURMJob is used to get a specific SLURM job for an authenticated user. For getting SLURM Jobs from an agent, please use the SLURMJobsAgentService.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.slurm_jobs_user_service_get_user_slurm_job(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: V1SLURMJob
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.slurm_jobs_user_service_get_user_slurm_job_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.slurm_jobs_user_service_get_user_slurm_job_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def slurm_jobs_user_service_get_user_slurm_job_with_http_info(self, project_id: 'str', id: 'str', **kwargs) -> 'V1SLURMJob':  # noqa: E501
        """GetUserSLURMJob is used to get a specific SLURM job for an authenticated user. For getting SLURM Jobs from an agent, please use the SLURMJobsAgentService.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.slurm_jobs_user_service_get_user_slurm_job_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: V1SLURMJob
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method slurm_jobs_user_service_get_user_slurm_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `slurm_jobs_user_service_get_user_slurm_job`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `slurm_jobs_user_service_get_user_slurm_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/slurm/jobs/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1SLURMJob',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def slurm_jobs_user_service_get_user_slurm_job_logs(self, project_id: 'str', id: 'str', **kwargs) -> 'V1LogsResponse':  # noqa: E501
        """GetUserSLURMJobLogs is used to get the logs of a specific SLURM job for an authenticated user. For getting SLURM Job logs from an agent, please use the SLURMJobsAgentService.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.slurm_jobs_user_service_get_user_slurm_job_logs(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str since:
        :param str until:
        :return: V1LogsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.slurm_jobs_user_service_get_user_slurm_job_logs_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.slurm_jobs_user_service_get_user_slurm_job_logs_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def slurm_jobs_user_service_get_user_slurm_job_logs_with_http_info(self, project_id: 'str', id: 'str', **kwargs) -> 'V1LogsResponse':  # noqa: E501
        """GetUserSLURMJobLogs is used to get the logs of a specific SLURM job for an authenticated user. For getting SLURM Job logs from an agent, please use the SLURMJobsAgentService.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.slurm_jobs_user_service_get_user_slurm_job_logs_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str since:
        :param str until:
        :return: V1LogsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'since', 'until']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method slurm_jobs_user_service_get_user_slurm_job_logs" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `slurm_jobs_user_service_get_user_slurm_job_logs`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `slurm_jobs_user_service_get_user_slurm_job_logs`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'since' in params:
            query_params.append(('since', params['since']))  # noqa: E501
        if 'until' in params:
            query_params.append(('until', params['until']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/slurm/jobs/{id}/logs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1LogsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def slurm_jobs_user_service_list_user_slurm_jobs(self, project_id: 'str', **kwargs) -> 'V1ListUserSLURMJobsResponse':  # noqa: E501
        """ListUserSLURMJobs is used to list all SLURM jobs for an authenticated user. For listing SLURM Jobs from an agent, please use the SLURMJobsAgentService.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.slurm_jobs_user_service_list_user_slurm_jobs(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param list[str] cloudspace_ids: optional. if not provided, will list all jobs for the project in all cloudspaces.
        :param list[str] cluster_id_in:
        :param list[str] cluster_id_not_in:
        :param list[str] state_in:
        :return: V1ListUserSLURMJobsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.slurm_jobs_user_service_list_user_slurm_jobs_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.slurm_jobs_user_service_list_user_slurm_jobs_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def slurm_jobs_user_service_list_user_slurm_jobs_with_http_info(self, project_id: 'str', **kwargs) -> 'V1ListUserSLURMJobsResponse':  # noqa: E501
        """ListUserSLURMJobs is used to list all SLURM jobs for an authenticated user. For listing SLURM Jobs from an agent, please use the SLURMJobsAgentService.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.slurm_jobs_user_service_list_user_slurm_jobs_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param list[str] cloudspace_ids: optional. if not provided, will list all jobs for the project in all cloudspaces.
        :param list[str] cluster_id_in:
        :param list[str] cluster_id_not_in:
        :param list[str] state_in:
        :return: V1ListUserSLURMJobsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'cloudspace_ids', 'cluster_id_in', 'cluster_id_not_in', 'state_in']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method slurm_jobs_user_service_list_user_slurm_jobs" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `slurm_jobs_user_service_list_user_slurm_jobs`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []
        if 'cloudspace_ids' in params:
            query_params.append(('cloudspaceIds', params['cloudspace_ids']))  # noqa: E501
            collection_formats['cloudspaceIds'] = 'multi'  # noqa: E501
        if 'cluster_id_in' in params:
            query_params.append(('clusterIdIn', params['cluster_id_in']))  # noqa: E501
            collection_formats['clusterIdIn'] = 'multi'  # noqa: E501
        if 'cluster_id_not_in' in params:
            query_params.append(('clusterIdNotIn', params['cluster_id_not_in']))  # noqa: E501
            collection_formats['clusterIdNotIn'] = 'multi'  # noqa: E501
        if 'state_in' in params:
            query_params.append(('stateIn', params['state_in']))  # noqa: E501
            collection_formats['stateIn'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/slurm/jobs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListUserSLURMJobsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def slurm_jobs_user_service_update_user_slurm_job(self, body: 'JobsIdBody1', project_id: 'str', id: 'str', **kwargs) -> 'V1SLURMJob':  # noqa: E501
        """UpdateUserSLURMJob is used to update a specific SLURM job for an authenticated user. For updating SLURM Jobs from an agent, please use the SLURMJobsAgentService.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.slurm_jobs_user_service_update_user_slurm_job(body, project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param JobsIdBody1 body: (required)
        :param str project_id: (required)
        :param str id: (required)
        :return: V1SLURMJob
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.slurm_jobs_user_service_update_user_slurm_job_with_http_info(body, project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.slurm_jobs_user_service_update_user_slurm_job_with_http_info(body, project_id, id, **kwargs)  # noqa: E501
            return data

    def slurm_jobs_user_service_update_user_slurm_job_with_http_info(self, body: 'JobsIdBody1', project_id: 'str', id: 'str', **kwargs) -> 'V1SLURMJob':  # noqa: E501
        """UpdateUserSLURMJob is used to update a specific SLURM job for an authenticated user. For updating SLURM Jobs from an agent, please use the SLURMJobsAgentService.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.slurm_jobs_user_service_update_user_slurm_job_with_http_info(body, project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param JobsIdBody1 body: (required)
        :param str project_id: (required)
        :param str id: (required)
        :return: V1SLURMJob
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method slurm_jobs_user_service_update_user_slurm_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `slurm_jobs_user_service_update_user_slurm_job`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `slurm_jobs_user_service_update_user_slurm_job`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `slurm_jobs_user_service_update_user_slurm_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/slurm/jobs/{id}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1SLURMJob',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def slurm_jobs_user_service_user_slurm_job_action(self, body: 'IdActionBody', project_id: 'str', id: 'str', **kwargs) -> 'V1UserSLURMJobActionResponse':  # noqa: E501
        """UserSLURMJobAction can be used to call an action on a specific SLURM job. For  example cancel the job.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.slurm_jobs_user_service_user_slurm_job_action(body, project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdActionBody body: (required)
        :param str project_id: (required)
        :param str id: (required)
        :return: V1UserSLURMJobActionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.slurm_jobs_user_service_user_slurm_job_action_with_http_info(body, project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.slurm_jobs_user_service_user_slurm_job_action_with_http_info(body, project_id, id, **kwargs)  # noqa: E501
            return data

    def slurm_jobs_user_service_user_slurm_job_action_with_http_info(self, body: 'IdActionBody', project_id: 'str', id: 'str', **kwargs) -> 'V1UserSLURMJobActionResponse':  # noqa: E501
        """UserSLURMJobAction can be used to call an action on a specific SLURM job. For  example cancel the job.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.slurm_jobs_user_service_user_slurm_job_action_with_http_info(body, project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdActionBody body: (required)
        :param str project_id: (required)
        :param str id: (required)
        :return: V1UserSLURMJobActionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method slurm_jobs_user_service_user_slurm_job_action" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `slurm_jobs_user_service_user_slurm_job_action`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `slurm_jobs_user_service_user_slurm_job_action`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `slurm_jobs_user_service_user_slurm_job_action`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/slurm/jobs/{id}/action', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1UserSLURMJobActionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1CloudSpaceInstanceConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'compute_config': 'V1UserRequestedComputeConfig',
        'data_connection_mounts': 'list[V1DataConnectionMount]',
        'disable_auto_shutdown': 'bool',
        'ide': 'str',
        'publish_with_compute_name': 'str'
    }

    attribute_map = {
        'compute_config': 'computeConfig',
        'data_connection_mounts': 'dataConnectionMounts',
        'disable_auto_shutdown': 'disableAutoShutdown',
        'ide': 'ide',
        'publish_with_compute_name': 'publishWithComputeName'
    }

    def __init__(self, compute_config: 'V1UserRequestedComputeConfig' =None, data_connection_mounts: 'list[V1DataConnectionMount]' =None, disable_auto_shutdown: 'bool' =None, ide: 'str' =None, publish_with_compute_name: 'str' =None):  # noqa: E501
        """V1CloudSpaceInstanceConfig - a model defined in Swagger"""  # noqa: E501
        self._compute_config = None
        self._data_connection_mounts = None
        self._disable_auto_shutdown = None
        self._ide = None
        self._publish_with_compute_name = None
        self.discriminator = None
        if compute_config is not None:
            self.compute_config = compute_config
        if data_connection_mounts is not None:
            self.data_connection_mounts = data_connection_mounts
        if disable_auto_shutdown is not None:
            self.disable_auto_shutdown = disable_auto_shutdown
        if ide is not None:
            self.ide = ide
        if publish_with_compute_name is not None:
            self.publish_with_compute_name = publish_with_compute_name

    @property
    def compute_config(self) -> 'V1UserRequestedComputeConfig':
        """Gets the compute_config of this V1CloudSpaceInstanceConfig.  # noqa: E501


        :return: The compute_config of this V1CloudSpaceInstanceConfig.  # noqa: E501
        :rtype: V1UserRequestedComputeConfig
        """
        return self._compute_config

    @compute_config.setter
    def compute_config(self, compute_config: 'V1UserRequestedComputeConfig'):
        """Sets the compute_config of this V1CloudSpaceInstanceConfig.


        :param compute_config: The compute_config of this V1CloudSpaceInstanceConfig.  # noqa: E501
        :type: V1UserRequestedComputeConfig
        """

        self._compute_config = compute_config

    @property
    def data_connection_mounts(self) -> 'list[V1DataConnectionMount]':
        """Gets the data_connection_mounts of this V1CloudSpaceInstanceConfig.  # noqa: E501


        :return: The data_connection_mounts of this V1CloudSpaceInstanceConfig.  # noqa: E501
        :rtype: list[V1DataConnectionMount]
        """
        return self._data_connection_mounts

    @data_connection_mounts.setter
    def data_connection_mounts(self, data_connection_mounts: 'list[V1DataConnectionMount]'):
        """Sets the data_connection_mounts of this V1CloudSpaceInstanceConfig.


        :param data_connection_mounts: The data_connection_mounts of this V1CloudSpaceInstanceConfig.  # noqa: E501
        :type: list[V1DataConnectionMount]
        """

        self._data_connection_mounts = data_connection_mounts

    @property
    def disable_auto_shutdown(self) -> 'bool':
        """Gets the disable_auto_shutdown of this V1CloudSpaceInstanceConfig.  # noqa: E501


        :return: The disable_auto_shutdown of this V1CloudSpaceInstanceConfig.  # noqa: E501
        :rtype: bool
        """
        return self._disable_auto_shutdown

    @disable_auto_shutdown.setter
    def disable_auto_shutdown(self, disable_auto_shutdown: 'bool'):
        """Sets the disable_auto_shutdown of this V1CloudSpaceInstanceConfig.


        :param disable_auto_shutdown: The disable_auto_shutdown of this V1CloudSpaceInstanceConfig.  # noqa: E501
        :type: bool
        """

        self._disable_auto_shutdown = disable_auto_shutdown

    @property
    def ide(self) -> 'str':
        """Gets the ide of this V1CloudSpaceInstanceConfig.  # noqa: E501


        :return: The ide of this V1CloudSpaceInstanceConfig.  # noqa: E501
        :rtype: str
        """
        return self._ide

    @ide.setter
    def ide(self, ide: 'str'):
        """Sets the ide of this V1CloudSpaceInstanceConfig.


        :param ide: The ide of this V1CloudSpaceInstanceConfig.  # noqa: E501
        :type: str
        """

        self._ide = ide

    @property
    def publish_with_compute_name(self) -> 'str':
        """Gets the publish_with_compute_name of this V1CloudSpaceInstanceConfig.  # noqa: E501


        :return: The publish_with_compute_name of this V1CloudSpaceInstanceConfig.  # noqa: E501
        :rtype: str
        """
        return self._publish_with_compute_name

    @publish_with_compute_name.setter
    def publish_with_compute_name(self, publish_with_compute_name: 'str'):
        """Sets the publish_with_compute_name of this V1CloudSpaceInstanceConfig.


        :param publish_with_compute_name: The publish_with_compute_name of this V1CloudSpaceInstanceConfig.  # noqa: E501
        :type: str
        """

        self._publish_with_compute_name = publish_with_compute_name

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1CloudSpaceInstanceConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1CloudSpaceInstanceConfig') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1CloudSpaceInstanceConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1CloudSpaceInstanceConfig') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1StorageSystemMetrics(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'percentage': 'int',
        'total': 'int',
        'used': 'int'
    }

    attribute_map = {
        'percentage': 'percentage',
        'total': 'total',
        'used': 'used'
    }

    def __init__(self, percentage: 'int' =None, total: 'int' =None, used: 'int' =None):  # noqa: E501
        """V1StorageSystemMetrics - a model defined in Swagger"""  # noqa: E501
        self._percentage = None
        self._total = None
        self._used = None
        self.discriminator = None
        if percentage is not None:
            self.percentage = percentage
        if total is not None:
            self.total = total
        if used is not None:
            self.used = used

    @property
    def percentage(self) -> 'int':
        """Gets the percentage of this V1StorageSystemMetrics.  # noqa: E501


        :return: The percentage of this V1StorageSystemMetrics.  # noqa: E501
        :rtype: int
        """
        return self._percentage

    @percentage.setter
    def percentage(self, percentage: 'int'):
        """Sets the percentage of this V1StorageSystemMetrics.


        :param percentage: The percentage of this V1StorageSystemMetrics.  # noqa: E501
        :type: int
        """

        self._percentage = percentage

    @property
    def total(self) -> 'int':
        """Gets the total of this V1StorageSystemMetrics.  # noqa: E501


        :return: The total of this V1StorageSystemMetrics.  # noqa: E501
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total: 'int'):
        """Sets the total of this V1StorageSystemMetrics.


        :param total: The total of this V1StorageSystemMetrics.  # noqa: E501
        :type: int
        """

        self._total = total

    @property
    def used(self) -> 'int':
        """Gets the used of this V1StorageSystemMetrics.  # noqa: E501


        :return: The used of this V1StorageSystemMetrics.  # noqa: E501
        :rtype: int
        """
        return self._used

    @used.setter
    def used(self, used: 'int'):
        """Sets the used of this V1StorageSystemMetrics.


        :param used: The used of this V1StorageSystemMetrics.  # noqa: E501
        :type: int
        """

        self._used = used

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1StorageSystemMetrics, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1StorageSystemMetrics') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1StorageSystemMetrics):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1StorageSystemMetrics') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1ClusterSpec(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'auth_token': 'str',
        'available_instance_types': 'list[str]',
        'aws_v1': 'V1AWSDirectV1',
        'cluster_type': 'V1ClusterType',
        'cost_factor': 'str',
        'deletion_options': 'V1ClusterDeletionOptions',
        'desired_state': 'V1ClusterState',
        'driver': 'V1ClusterDriver',
        'google_cloud_v1': 'V1GoogleCloudDirectV1',
        'gridlet_version': 'str',
        'overprovisioning': 'list[V1InstanceOverprovisioningSpec]',
        'padding_factor': 'str',
        'pause_automation': 'bool',
        'performance_profile': 'V1ClusterPerformanceProfile',
        'slurm_v1': 'V1SlurmV1',
        'user_id': 'str'
    }

    attribute_map = {
        'auth_token': 'authToken',
        'available_instance_types': 'availableInstanceTypes',
        'aws_v1': 'awsV1',
        'cluster_type': 'clusterType',
        'cost_factor': 'costFactor',
        'deletion_options': 'deletionOptions',
        'desired_state': 'desiredState',
        'driver': 'driver',
        'google_cloud_v1': 'googleCloudV1',
        'gridlet_version': 'gridletVersion',
        'overprovisioning': 'overprovisioning',
        'padding_factor': 'paddingFactor',
        'pause_automation': 'pauseAutomation',
        'performance_profile': 'performanceProfile',
        'slurm_v1': 'slurmV1',
        'user_id': 'userId'
    }

    def __init__(self, auth_token: 'str' =None, available_instance_types: 'list[str]' =None, aws_v1: 'V1AWSDirectV1' =None, cluster_type: 'V1ClusterType' =None, cost_factor: 'str' =None, deletion_options: 'V1ClusterDeletionOptions' =None, desired_state: 'V1ClusterState' =None, driver: 'V1ClusterDriver' =None, google_cloud_v1: 'V1GoogleCloudDirectV1' =None, gridlet_version: 'str' =None, overprovisioning: 'list[V1InstanceOverprovisioningSpec]' =None, padding_factor: 'str' =None, pause_automation: 'bool' =None, performance_profile: 'V1ClusterPerformanceProfile' =None, slurm_v1: 'V1SlurmV1' =None, user_id: 'str' =None):  # noqa: E501
        """V1ClusterSpec - a model defined in Swagger"""  # noqa: E501
        self._auth_token = None
        self._available_instance_types = None
        self._aws_v1 = None
        self._cluster_type = None
        self._cost_factor = None
        self._deletion_options = None
        self._desired_state = None
        self._driver = None
        self._google_cloud_v1 = None
        self._gridlet_version = None
        self._overprovisioning = None
        self._padding_factor = None
        self._pause_automation = None
        self._performance_profile = None
        self._slurm_v1 = None
        self._user_id = None
        self.discriminator = None
        if auth_token is not None:
            self.auth_token = auth_token
        if available_instance_types is not None:
            self.available_instance_types = available_instance_types
        if aws_v1 is not None:
            self.aws_v1 = aws_v1
        if cluster_type is not None:
            self.cluster_type = cluster_type
        if cost_factor is not None:
            self.cost_factor = cost_factor
        if deletion_options is not None:
            self.deletion_options = deletion_options
        if desired_state is not None:
            self.desired_state = desired_state
        if driver is not None:
            self.driver = driver
        if google_cloud_v1 is not None:
            self.google_cloud_v1 = google_cloud_v1
        if gridlet_version is not None:
            self.gridlet_version = gridlet_version
        if overprovisioning is not None:
            self.overprovisioning = overprovisioning
        if padding_factor is not None:
            self.padding_factor = padding_factor
        if pause_automation is not None:
            self.pause_automation = pause_automation
        if performance_profile is not None:
            self.performance_profile = performance_profile
        if slurm_v1 is not None:
            self.slurm_v1 = slurm_v1
        if user_id is not None:
            self.user_id = user_id

    @property
    def auth_token(self) -> 'str':
        """Gets the auth_token of this V1ClusterSpec.  # noqa: E501


        :return: The auth_token of this V1ClusterSpec.  # noqa: E501
        :rtype: str
        """
        return self._auth_token

    @auth_token.setter
    def auth_token(self, auth_token: 'str'):
        """Sets the auth_token of this V1ClusterSpec.


        :param auth_token: The auth_token of this V1ClusterSpec.  # noqa: E501
        :type: str
        """

        self._auth_token = auth_token

    @property
    def available_instance_types(self) -> 'list[str]':
        """Gets the available_instance_types of this V1ClusterSpec.  # noqa: E501

        available_instance_types is a list of instance types that are available for the cluster. This is just a soft filter to prevent users from using instances that we haven't prepared for. If the list is empty, no filtering is done.  # noqa: E501

        :return: The available_instance_types of this V1ClusterSpec.  # noqa: E501
        :rtype: list[str]
        """
        return self._available_instance_types

    @available_instance_types.setter
    def available_instance_types(self, available_instance_types: 'list[str]'):
        """Sets the available_instance_types of this V1ClusterSpec.

        available_instance_types is a list of instance types that are available for the cluster. This is just a soft filter to prevent users from using instances that we haven't prepared for. If the list is empty, no filtering is done.  # noqa: E501

        :param available_instance_types: The available_instance_types of this V1ClusterSpec.  # noqa: E501
        :type: list[str]
        """

        self._available_instance_types = available_instance_types

    @property
    def aws_v1(self) -> 'V1AWSDirectV1':
        """Gets the aws_v1 of this V1ClusterSpec.  # noqa: E501


        :return: The aws_v1 of this V1ClusterSpec.  # noqa: E501
        :rtype: V1AWSDirectV1
        """
        return self._aws_v1

    @aws_v1.setter
    def aws_v1(self, aws_v1: 'V1AWSDirectV1'):
        """Sets the aws_v1 of this V1ClusterSpec.


        :param aws_v1: The aws_v1 of this V1ClusterSpec.  # noqa: E501
        :type: V1AWSDirectV1
        """

        self._aws_v1 = aws_v1

    @property
    def cluster_type(self) -> 'V1ClusterType':
        """Gets the cluster_type of this V1ClusterSpec.  # noqa: E501


        :return: The cluster_type of this V1ClusterSpec.  # noqa: E501
        :rtype: V1ClusterType
        """
        return self._cluster_type

    @cluster_type.setter
    def cluster_type(self, cluster_type: 'V1ClusterType'):
        """Sets the cluster_type of this V1ClusterSpec.


        :param cluster_type: The cluster_type of this V1ClusterSpec.  # noqa: E501
        :type: V1ClusterType
        """

        self._cluster_type = cluster_type

    @property
    def cost_factor(self) -> 'str':
        """Gets the cost_factor of this V1ClusterSpec.  # noqa: E501

        costController needs for calculating costOfGoods - string since it's decimal. Note: This value is stored in a separate column in the database, not with the rest of the cluster JSON in spec.  # noqa: E501

        :return: The cost_factor of this V1ClusterSpec.  # noqa: E501
        :rtype: str
        """
        return self._cost_factor

    @cost_factor.setter
    def cost_factor(self, cost_factor: 'str'):
        """Sets the cost_factor of this V1ClusterSpec.

        costController needs for calculating costOfGoods - string since it's decimal. Note: This value is stored in a separate column in the database, not with the rest of the cluster JSON in spec.  # noqa: E501

        :param cost_factor: The cost_factor of this V1ClusterSpec.  # noqa: E501
        :type: str
        """

        self._cost_factor = cost_factor

    @property
    def deletion_options(self) -> 'V1ClusterDeletionOptions':
        """Gets the deletion_options of this V1ClusterSpec.  # noqa: E501


        :return: The deletion_options of this V1ClusterSpec.  # noqa: E501
        :rtype: V1ClusterDeletionOptions
        """
        return self._deletion_options

    @deletion_options.setter
    def deletion_options(self, deletion_options: 'V1ClusterDeletionOptions'):
        """Sets the deletion_options of this V1ClusterSpec.


        :param deletion_options: The deletion_options of this V1ClusterSpec.  # noqa: E501
        :type: V1ClusterDeletionOptions
        """

        self._deletion_options = deletion_options

    @property
    def desired_state(self) -> 'V1ClusterState':
        """Gets the desired_state of this V1ClusterSpec.  # noqa: E501


        :return: The desired_state of this V1ClusterSpec.  # noqa: E501
        :rtype: V1ClusterState
        """
        return self._desired_state

    @desired_state.setter
    def desired_state(self, desired_state: 'V1ClusterState'):
        """Sets the desired_state of this V1ClusterSpec.


        :param desired_state: The desired_state of this V1ClusterSpec.  # noqa: E501
        :type: V1ClusterState
        """

        self._desired_state = desired_state

    @property
    def driver(self) -> 'V1ClusterDriver':
        """Gets the driver of this V1ClusterSpec.  # noqa: E501


        :return: The driver of this V1ClusterSpec.  # noqa: E501
        :rtype: V1ClusterDriver
        """
        return self._driver

    @driver.setter
    def driver(self, driver: 'V1ClusterDriver'):
        """Sets the driver of this V1ClusterSpec.


        :param driver: The driver of this V1ClusterSpec.  # noqa: E501
        :type: V1ClusterDriver
        """

        self._driver = driver

    @property
    def google_cloud_v1(self) -> 'V1GoogleCloudDirectV1':
        """Gets the google_cloud_v1 of this V1ClusterSpec.  # noqa: E501


        :return: The google_cloud_v1 of this V1ClusterSpec.  # noqa: E501
        :rtype: V1GoogleCloudDirectV1
        """
        return self._google_cloud_v1

    @google_cloud_v1.setter
    def google_cloud_v1(self, google_cloud_v1: 'V1GoogleCloudDirectV1'):
        """Sets the google_cloud_v1 of this V1ClusterSpec.


        :param google_cloud_v1: The google_cloud_v1 of this V1ClusterSpec.  # noqa: E501
        :type: V1GoogleCloudDirectV1
        """

        self._google_cloud_v1 = google_cloud_v1

    @property
    def gridlet_version(self) -> 'str':
        """Gets the gridlet_version of this V1ClusterSpec.  # noqa: E501


        :return: The gridlet_version of this V1ClusterSpec.  # noqa: E501
        :rtype: str
        """
        return self._gridlet_version

    @gridlet_version.setter
    def gridlet_version(self, gridlet_version: 'str'):
        """Sets the gridlet_version of this V1ClusterSpec.


        :param gridlet_version: The gridlet_version of this V1ClusterSpec.  # noqa: E501
        :type: str
        """

        self._gridlet_version = gridlet_version

    @property
    def overprovisioning(self) -> 'list[V1InstanceOverprovisioningSpec]':
        """Gets the overprovisioning of this V1ClusterSpec.  # noqa: E501


        :return: The overprovisioning of this V1ClusterSpec.  # noqa: E501
        :rtype: list[V1InstanceOverprovisioningSpec]
        """
        return self._overprovisioning

    @overprovisioning.setter
    def overprovisioning(self, overprovisioning: 'list[V1InstanceOverprovisioningSpec]'):
        """Sets the overprovisioning of this V1ClusterSpec.


        :param overprovisioning: The overprovisioning of this V1ClusterSpec.  # noqa: E501
        :type: list[V1InstanceOverprovisioningSpec]
        """

        self._overprovisioning = overprovisioning

    @property
    def padding_factor(self) -> 'str':
        """Gets the padding_factor of this V1ClusterSpec.  # noqa: E501

        costController needs for calculating paddingValue - string since it's decimal Note: This value is stored in a separate column in the database, not with the rest of the cluster JSON in spec.  # noqa: E501

        :return: The padding_factor of this V1ClusterSpec.  # noqa: E501
        :rtype: str
        """
        return self._padding_factor

    @padding_factor.setter
    def padding_factor(self, padding_factor: 'str'):
        """Sets the padding_factor of this V1ClusterSpec.

        costController needs for calculating paddingValue - string since it's decimal Note: This value is stored in a separate column in the database, not with the rest of the cluster JSON in spec.  # noqa: E501

        :param padding_factor: The padding_factor of this V1ClusterSpec.  # noqa: E501
        :type: str
        """

        self._padding_factor = padding_factor

    @property
    def pause_automation(self) -> 'bool':
        """Gets the pause_automation of this V1ClusterSpec.  # noqa: E501


        :return: The pause_automation of this V1ClusterSpec.  # noqa: E501
        :rtype: bool
        """
        return self._pause_automation

    @pause_automation.setter
    def pause_automation(self, pause_automation: 'bool'):
        """Sets the pause_automation of this V1ClusterSpec.


        :param pause_automation: The pause_automation of this V1ClusterSpec.  # noqa: E501
        :type: bool
        """

        self._pause_automation = pause_automation

    @property
    def performance_profile(self) -> 'V1ClusterPerformanceProfile':
        """Gets the performance_profile of this V1ClusterSpec.  # noqa: E501


        :return: The performance_profile of this V1ClusterSpec.  # noqa: E501
        :rtype: V1ClusterPerformanceProfile
        """
        return self._performance_profile

    @performance_profile.setter
    def performance_profile(self, performance_profile: 'V1ClusterPerformanceProfile'):
        """Sets the performance_profile of this V1ClusterSpec.


        :param performance_profile: The performance_profile of this V1ClusterSpec.  # noqa: E501
        :type: V1ClusterPerformanceProfile
        """

        self._performance_profile = performance_profile

    @property
    def slurm_v1(self) -> 'V1SlurmV1':
        """Gets the slurm_v1 of this V1ClusterSpec.  # noqa: E501


        :return: The slurm_v1 of this V1ClusterSpec.  # noqa: E501
        :rtype: V1SlurmV1
        """
        return self._slurm_v1

    @slurm_v1.setter
    def slurm_v1(self, slurm_v1: 'V1SlurmV1'):
        """Sets the slurm_v1 of this V1ClusterSpec.


        :param slurm_v1: The slurm_v1 of this V1ClusterSpec.  # noqa: E501
        :type: V1SlurmV1
        """

        self._slurm_v1 = slurm_v1

    @property
    def user_id(self) -> 'str':
        """Gets the user_id of this V1ClusterSpec.  # noqa: E501


        :return: The user_id of this V1ClusterSpec.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id: 'str'):
        """Sets the user_id of this V1ClusterSpec.


        :param user_id: The user_id of this V1ClusterSpec.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1ClusterSpec, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1ClusterSpec') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ClusterSpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1ClusterSpec') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# from lightning.utilities.network import find_free_network_port
import socket


def find_free_network_port() -> int:
    """Finds a free port on localhost."""
    try:
        with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as sock:
            sock.bind(("", 0))
            sock.listen(1)
            return sock.getsockname()[1]
    except BaseException:
        return find_free_network_port()



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1Plugin(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'additional_info': 'str',
        'error': 'str',
        'id': 'str',
        'plugin_id': 'str',
        'project_id': 'str',
        'state': 'str'
    }

    attribute_map = {
        'additional_info': 'additionalInfo',
        'error': 'error',
        'id': 'id',
        'plugin_id': 'pluginId',
        'project_id': 'projectId',
        'state': 'state'
    }

    def __init__(self, additional_info: 'str' =None, error: 'str' =None, id: 'str' =None, plugin_id: 'str' =None, project_id: 'str' =None, state: 'str' =None):  # noqa: E501
        """V1Plugin - a model defined in Swagger"""  # noqa: E501
        self._additional_info = None
        self._error = None
        self._id = None
        self._plugin_id = None
        self._project_id = None
        self._state = None
        self.discriminator = None
        if additional_info is not None:
            self.additional_info = additional_info
        if error is not None:
            self.error = error
        if id is not None:
            self.id = id
        if plugin_id is not None:
            self.plugin_id = plugin_id
        if project_id is not None:
            self.project_id = project_id
        if state is not None:
            self.state = state

    @property
    def additional_info(self) -> 'str':
        """Gets the additional_info of this V1Plugin.  # noqa: E501


        :return: The additional_info of this V1Plugin.  # noqa: E501
        :rtype: str
        """
        return self._additional_info

    @additional_info.setter
    def additional_info(self, additional_info: 'str'):
        """Sets the additional_info of this V1Plugin.


        :param additional_info: The additional_info of this V1Plugin.  # noqa: E501
        :type: str
        """

        self._additional_info = additional_info

    @property
    def error(self) -> 'str':
        """Gets the error of this V1Plugin.  # noqa: E501


        :return: The error of this V1Plugin.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error: 'str'):
        """Sets the error of this V1Plugin.


        :param error: The error of this V1Plugin.  # noqa: E501
        :type: str
        """

        self._error = error

    @property
    def id(self) -> 'str':
        """Gets the id of this V1Plugin.  # noqa: E501


        :return: The id of this V1Plugin.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1Plugin.


        :param id: The id of this V1Plugin.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def plugin_id(self) -> 'str':
        """Gets the plugin_id of this V1Plugin.  # noqa: E501


        :return: The plugin_id of this V1Plugin.  # noqa: E501
        :rtype: str
        """
        return self._plugin_id

    @plugin_id.setter
    def plugin_id(self, plugin_id: 'str'):
        """Sets the plugin_id of this V1Plugin.


        :param plugin_id: The plugin_id of this V1Plugin.  # noqa: E501
        :type: str
        """

        self._plugin_id = plugin_id

    @property
    def project_id(self) -> 'str':
        """Gets the project_id of this V1Plugin.  # noqa: E501


        :return: The project_id of this V1Plugin.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id: 'str'):
        """Sets the project_id of this V1Plugin.


        :param project_id: The project_id of this V1Plugin.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def state(self) -> 'str':
        """Gets the state of this V1Plugin.  # noqa: E501


        :return: The state of this V1Plugin.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state: 'str'):
        """Sets the state of this V1Plugin.


        :param state: The state of this V1Plugin.  # noqa: E501
        :type: str
        """

        self._state = state

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1Plugin, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1Plugin') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1Plugin):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1Plugin') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other
